function [solution] = SSP_rSDP(A)
%
%   Solving relaxed-SDP problem to track the lower bound of the SSP using
%   YALMIP interface and SDPNAL solver i.e.
%
%                       min lambda1
%              s.t. (1) -I + nu1(A'*A) - lambda_1 * 1 + 2*Lambda_2
%                   (2) 0 <= Lambda_2 <= lambda_1 * 1
%
%   Inputs:
%   'A'         Sensing matrix m-by-n where m < n
%
%   Outputs:
%   'Solution'  Solved paramteres
%
%
%   (c) Mahdi S. Hosseini
%       PhD Candidate, University of Toronto, Oct 2012
%       mahdi.hosseini@utoronto.ca
%
%   [Ref] Mahdi S. Hosseini, Siavash Fazeli-Dehkordy and Konstantinos N.
%   Plataniotis, "Tractable Bound for Spherical Section Property in the
%                 Presence of Side-Information," IEEE Signal Processing
%                 Letters, vol.19, no.8, pp.519-522, Aug. 2012.
%   [url]
%   http://ieeexplore.ieee.org/xpl/articleDetails.jsp?arnumber=6220237

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%% Proposed SDP in YALMIP Language %%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
[m, n] = size(A);
Lambda2 = sdpvar(n, n);
nu1 = sdpvar(1);
nu2 = sdpvar(1);
lambda1 = sdpvar(1);
I = speye(n);
II = ones(n);
F_CS = set(-I + nu1*(A'*A) - lambda1*II + 2*Lambda2 >= 0);
F = F_CS;
F = F + set(0<=Lambda2(find(triu(ones(n))))<=lambda1);
solution = solvesdp(F, lambda1, ...
    sdpsettings('solver','sdpnal', 'verbose', 1));
